<?php
/**
 * Plugin Name: sourceplay-navermap
 * Description: 네이버 지도 API 활용
 * Version: 0.0.2
 * Author: 소스놀이터(SourcePlayground)
 * Author URI: https://zooo.kr/fxbbs/naver_map_plugin.php
*/

define('SOURCE_PLAYGROUND_PATH', plugins_url('', __FILE__));

add_action('admin_menu', 'source_playground_menu_setting');
function source_playground_menu_setting(){
	global $wpdb, $_wp_last_object_menu;

	$_wp_last_object_menu++;
	add_menu_page(__('네이버 지도(소스놀이터)', 'source-playground'), 'NaverMap', 'manage_options', 'source_playground_index', 'source_playground_index', 'dashicons-admin-site', $_wp_last_object_menu);

	add_submenu_page('source_playground_index', '네이버 지도(소스놀이터)', __('추가하기', 'NaverMap'), 'manage_options', 'sourceplay_navermap_add', 'sourceplay_navermap_add');
}

// [sourceplay-navermap id="2"]
function shortcode_sourceplay_navermap( $atts ) {
	global $wpdb;

	$a = shortcode_atts( array(
		'id' => ''
	), $atts );

	$a_id = (int) $a['id'];

	$rs_map = $wpdb->get_row( $wpdb->prepare(" SELECT nmap_code, apply_method, client_id, address, descript, lng, lat, now_date, width, height FROM ".$wpdb->prefix."sourceplay_navermap where nmap_code=%d ",array($a_id)));

	$return_html = wp_enqueue_script('naveropenapi js', "//openapi.map.naver.com/openapi/v3/maps.js?ncpClientId=".esc_attr($rs_map->client_id)."&submodules=geocoder", array(), '0.0.0');

	$return_html .= "
	<div id='map".esc_html($a_id)."' style='width:".esc_html($rs_map->width)."; height:".esc_html($rs_map->height)."'></div>
	<script>
		setTimeout(function(){
			 var map".esc_js($a_id)." = new naver.maps.Map('map".esc_js($a_id)."', {
			 center: new naver.maps.LatLng(".esc_js($rs_map->lat).", ".esc_js($rs_map->lng)."),
			 mapTypeControl: true,
			 zoom: 15,
			 scaleControl: true,
			 logoControl: true,
			 mapDataControl: true,
			 zoomControl: true,
			 mapTypeControl: true,
			 draggable: true,
			 disableDoubleTapZoom: true,
			 disableTwoFingerTapZoom: true		 
			});

			var infoWindow".esc_js($a_id)." = new naver.maps.InfoWindow({
			  anchorSkew: true
			});

			 var htmlAddresses = [];
		
			 var item = new Object();
			 item.x = '".esc_js($rs_map->lng)."';
			 item.y = '".esc_js($rs_map->lat)."';

			 var point = new naver.maps.Point(item.x, item.y);

			 htmlAddresses.push('<div style=\"padding:0px; padding-left:10px; margin-top:5px; font-size:11px; line-height:110%\">".wp_kses_post($rs_map->descript)."</div>');

			 infoWindow".esc_js($a_id).".setContent([
				'<div style=\"padding:10px;min-width:200px;line-height:150%\">',
				'<h7 style=\"margin-top:5px; margin-bottom:5px; font-weight:bold\">'+ '".wp_kses_post($rs_map->address)."' +'</h7>',
				htmlAddresses,
				'</div>'
			 ].join('\\n'));

			 map".esc_js($a_id).".setCenter(point);
			 infoWindow".esc_js($a_id).".open(map".esc_js($a_id).", point);
		},2400);
	</script>
	";

	return $return_html;
}

add_shortcode( 'sourceplay-navermap', 'shortcode_sourceplay_navermap' );

add_action( 'admin_post_sourceplay_map_save', 'sourceplay_map_save' );
add_action( 'admin_post_sourceplay_map_delete', 'sourceplay_map_delete' );

add_action('plugins_loaded', 'source_playground_runUpdatedPlugin');
function source_playground_runUpdatedPlugin()
{
	global $wpdb;			
	if ( is_admin() ) {
		$address_length = $wpdb->get_row( $wpdb->prepare(" SELECT CHARACTER_MAXIMUM_LENGTH FROM information_schema.columns WHERE table_name ='".$wpdb->prefix."sourceplay_navermap' AND COLUMN_NAME='address' ", null))->CHARACTER_MAXIMUM_LENGTH;
		if($address_length < 1000) {
			$wpdb->query("alter table " . $wpdb->prefix . "sourceplay_navermap modify address varchar(1000)");
		}

		$descript_length = $wpdb->get_row( $wpdb->prepare(" SELECT CHARACTER_MAXIMUM_LENGTH FROM information_schema.columns WHERE table_name ='".$wpdb->prefix."sourceplay_navermap' AND COLUMN_NAME='descript' ", null))->CHARACTER_MAXIMUM_LENGTH;
		if($descript_length < 7000) {
			$wpdb->query("alter table " . $wpdb->prefix . "sourceplay_navermap modify descript varchar(7000)");
		}

	}
}

//새지도 생성 저장하기
function sourceplay_map_save()
{
	global $wpdb;

	$code = (int) $_POST["code"];
	if(!$code)  //INSERT
	{
		$table = $wpdb->prefix.'sourceplay_navermap';
		$data = array('apply_method' => sanitize_text_field($_POST["map_type"]), 'client_id' => sanitize_text_field($_POST["client_id"]), 'address' => wp_kses_post($_POST["address"]), 'descript' => wp_kses_post($_POST["descript"]), 'lng' => sanitize_text_field($_POST["lng"]), 'lat' => sanitize_text_field($_POST["lat"]), 'width' => sanitize_text_field($_POST["width"]), 'height' => sanitize_text_field($_POST["height"]));
		$format = array('%s','%s','%s','%s','%s','%s','%s','%s');
		$wpdb->insert($table,$data,$format);
		$my_nmap_code = $wpdb->insert_id;
		if($my_nmap_code)
		{
			echo "OK;".$my_nmap_code;
		}
	}
	else //UPDATE
	{
		$result = $wpdb->update( 
						$wpdb->prefix.'sourceplay_navermap', 
						array('apply_method' => sanitize_text_field($_POST["map_type"]), 'client_id' => sanitize_text_field($_POST["client_id"]), 'address' => wp_kses_post($_POST["address"]), 'descript' => wp_kses_post($_POST["descript"]), 'lng' => sanitize_text_field($_POST["lng"]), 'lat' => sanitize_text_field($_POST["lat"]), 'width' => sanitize_text_field($_POST["width"]), 'height' => sanitize_text_field($_POST["height"])), 
						array( 'nmap_code' => $code), 
						array('%s','%s','%s','%s','%s','%s','%s','%s'), 
						array( '%d' ) 
					);
		if($result === false) //에러인 경우
		{
		}
		else
		{
			echo "OK;".$code;
		}
	}
}

//지도 삭제하기
function sourceplay_map_delete()
{
	global $wpdb;

	$code = (int) $_POST["code"];
	if($code)
	{
		$state = $wpdb->delete( $wpdb->prefix."sourceplay_navermap", array( 'nmap_code' => $code) );
		if($state)
		{
			echo "OK";
		}
	}
}

function source_playground_index(){
	global $wpdb;
	wp_enqueue_style('sourceplay main', SOURCE_PLAYGROUND_PATH.'/css/sourceplay_main.css', array(), '0.0.1');
	wp_enqueue_style('sweetalert2 css', SOURCE_PLAYGROUND_PATH.'/css/sweetalert2.css', array(), '0.0.1');
	wp_enqueue_style('maplist css', SOURCE_PLAYGROUND_PATH.'/css/maplist.css', array(), '0.0.1');
	wp_enqueue_script('maplist js', SOURCE_PLAYGROUND_PATH . '/js/maplist.js', array(), '0.0.0');
	wp_enqueue_script('sweetalert2 js', SOURCE_PLAYGROUND_PATH . '/js/sweetalert2.min.js', array(), '0.0.0');
	wp_enqueue_script('bpopup2 js', SOURCE_PLAYGROUND_PATH . '/js/jquery.bpopup2.min.js', array(), '0.0.0');
	$map_list = $wpdb->get_results( "SELECT nmap_code, apply_method, client_id, address, lng, lat, now_date FROM ".$wpdb->prefix."sourceplay_navermap ORDER BY now_date desc" );

	include "maplist.php";
}

function sourceplay_navermap_add(){
	global $wpdb;
	wp_enqueue_style('sourceplay main', SOURCE_PLAYGROUND_PATH.'/css/sourceplay_main.css', array(), '0.0.1');
	wp_enqueue_style('mapadd css', SOURCE_PLAYGROUND_PATH.'/css/mapadd.css', array(), '0.0.1');
	wp_enqueue_style('sweetalert2 css', SOURCE_PLAYGROUND_PATH.'/css/sweetalert2.css', array(), '0.0.1');
	wp_enqueue_script('mapadd js', SOURCE_PLAYGROUND_PATH . '/js/mapadd.js', array(), '0.0.2');
	wp_enqueue_script('sweetalert2 js', SOURCE_PLAYGROUND_PATH . '/js/sweetalert2.min.js', array(), '0.0.0');
	wp_enqueue_script('bpopup2 js', SOURCE_PLAYGROUND_PATH . '/js/jquery.bpopup2.min.js', array(), '0.0.0');

	$NMAP_CODE = "";
	if(isset($_GET["code"])) {
		$NMAP_CODE = (int) $_GET["code"];
	}
	
	$RECENT_CLIENT_ID = "";
	$mode = "add";
	$rs_map = null;
	if($NMAP_CODE)
	{
		$mode = "modify";
		$rs_map = $wpdb->get_row( $wpdb->prepare(" SELECT nmap_code, apply_method, client_id, address, descript, lng, lat, now_date, width, height FROM ".$wpdb->prefix."sourceplay_navermap where nmap_code=%d ",array($NMAP_CODE)));
	}
	else
	{
		$RECENT_CLIENT_ID = $wpdb->get_var( $wpdb->prepare(" SELECT client_id FROM ".$wpdb->prefix."sourceplay_navermap order by now_date desc limit 1 ",array($NMAP_CODE)));
	}
	include "mapadd.php";
}

register_deactivation_hook(__FILE__, 'source_playground_deactivation');
function source_playground_deactivation($networkwide){
}

register_uninstall_hook(__FILE__, 'source_playground_uninstall');
function source_playground_uninstall(){
	global $wpdb;
	$wpdb->query("DROP TABLE `{$wpdb->prefix}sourceplay_navermap`");
}

/*
 * 활성화
 */
register_activation_hook(__FILE__, 'source_playground_activation');
function source_playground_activation(){
	global $wpdb;
	require_once ABSPATH . 'wp-admin/includes/upgrade.php';
	$charset_collate = $wpdb->get_charset_collate();
	
	$wpdb->query("CREATE TABLE IF NOT EXISTS `{$wpdb->prefix}sourceplay_navermap` (
	`nmap_code` INT(11) NOT NULL AUTO_INCREMENT,
	`apply_method` VARCHAR(30) NULL DEFAULT NULL,
	`client_id` VARCHAR(100) NOT NULL DEFAULT '0',
	`address` VARCHAR(1000) NOT NULL DEFAULT '0',
	`descript` VARCHAR(7000) NULL DEFAULT NULL,
	`lng` VARCHAR(100) NOT NULL DEFAULT '0',
	`lat` VARCHAR(100) NOT NULL DEFAULT '0',
	`width` VARCHAR(12) NULL DEFAULT NULL,
	`height` VARCHAR(12) NULL DEFAULT NULL,
	`now_date` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
	PRIMARY KEY (`nmap_code`)
	) {$charset_collate};");
}
?>